# Customer Success

## Overview

We at MayaData believe that the best way to deliver storage and related services to containerized and cloud-native environments is with containerized and cloud-native architectures. Everything we do is focused on providing data agility and simplifying the daily operation of Kubernetes SRE’s and DevOps teams using Kubernetes as a data layer. We enable our users to handle complex data management operations easily, and we have become open source leaders in building Kubernetes into a first-class data platform.

Customer Success is an important function at MayaData in the broader goal of achieving customer satisfaction.

As customer success engineers and architects, you are driven to make every customer, a reference customer; enable customers must grow their usage of our open source and commercial software and services substantially over time.

As customer success engineers and architects, you will collaborate with other departments in the organization to provide the best experience for our customers.

_**Customer Success Engineers directly interact with customers to help them quickly solve their problems and ensure customer satisfaction remains high.**_

Some of the essential skills required by Customer Success Engineers are:
* You share our [PLOW](/plow/plow.md) values - especially learning, openness and a sense of ownership.
* **Being Empathetic:** People in customer success roles should genuinely want to help other people. That desire begins with empathy: the willingness to understand another person’s experience and see it through their eyes. One proof of empathy is the ability to express the user’s needs in one’s own words.
* **Strong communicator:** This job is about communicating with other people. Customer Success Engineers need to communicate well both verbally and in writing. Communication is about listening, then clearly articulating ideas and information in an authentic way.
* **Master of simplicity:** When a customer makes the effort to reach out and ask for help, it’s the Customer Success Engineer’s job to quickly assess the problem, sort it all out, and then present the customer with the simplest answer possible.
* **Growth mindset:** Products, technology, and policies will change over time, and Customer Success Engineers will need to change with them.
* **Always learning:** Customer Success Engineers consistently demonstrate a drive for learning and growing. Strong inclination to certify yourself with latest Kubernetes certification such as CKA

Customer Success teams directly report to the *Chief Operations Officer - COO*, who ensures that the Customer Success teams are highly motivated and aligned to the [Organizational goals](https://github.com/mayadata-io/culture/blob/master/process/okr.md).

## Levels of Customer Success Engineers

As a customer success engineer, you will be responsible for users and customers of MayaData products are getting the best experience when they need support. At MayaData, we believe that users self adopt the projects and technology we build and eventually many of them require our support to scale their usage of Kubernetes as a data layer and to maintain their use of MayaData software and services production. As a customer success engineer, you provide an excellent experience to end-users, field teams, and the engineering team during this process.

### Junior Customer Success Engineer

* This is the team’s entry-level role. We look for people with potential, who have 0-2 years of experience helping customers in some capacity, and who possess essential customer support skills.
* Associates are in training and need guidance to perform at the standard level set for customer success engineers.
* The individuals in this role are well versed in the concepts and have undergone the OpenEBS training and workshop.
* The individuals in this role are expected to help customers by pointing in the right direction with the help of Documentation or KB articles, helping them navigate through OpenEBS and other products from MayaData.
* The individuals are expected to become comfortable with tools like Slack and ZenDesk and help with ensuring the customer tickets are updated.
* People are usually in this role for at least 3 months before becoming full-fledged Customer Success Engineers

### Customer Success Engineer

* Expert knowledge on Linux (Centos, Ubuntu, Debian, RedHat) with at least 1-2 years experience in system administration and support role.
* Customer Success Engineers have gained experience in installing the OpenEBS and other products from MayaData.
* Customer Success Engineers have the ability to determine the components that are potentially causing an issue.
* Customer Success Engineers are comfortable editing and updating the OpenEBS and Kubera documentation based on the interactions with the customers.
* Customer Success Engineers are the first point of contact for all incoming customer issues. These engineers handle all incoming chats and phone calls. This is where all incoming tickets are triaged and then routed to the appropriate team.
* Customer Success Engineers are expected to provide an initial response to issues within 15 minutes and resolve the issues within 30 minutes of being assigned. If a customer issue is more complex and requires more time to resolve, it’s assigned to Developer Advocate handling the feature.
* Be the driver for customer support calls and make sure that customers get the best experience.
* All the communication between the customer and the MayaData team should be documented in the ticketing system.
* Convert the tickets into relevant content in the MayaData help center through the troubleshooting and solution guides.
* Escalate the tickets to the next level if it doesn’t meet the SLA.
* Prepare, review, and maintain technical document. Ability to gather and analyse  product information from various sources to document new or update exisiting documents.
* Inclination towards getting CKA/CKAD certified.

### Lead Customer Success Engineer
In addition to the responsibilities defined above:
* Lead Customer Success Engineer must demonstrate that they can proactively identify problem areas and mentor and train other Customer Success Engineers on how to solve more difficult issues.
* They often specialize in one or more product areas and are considered experts in those areas.
* Leads are responsible for identifying the issues that are causing pain to the customers and are causing the customers to drop off. The issues need to be escalated to the Product Management team.
* Leads have the ability to learn about customer deployment and reproduce it internally.



### Engineering Manager - Customer Success

Customer Success Engineering manager is comfortable with all the responsibilities of a lead Customer Success Engineers and can play the role of the support engineer when the situation demands.

Customer Success Engineering Managers must believe that a great overall Customer Success experience can be achieved by being as concerned with the Customer Success Teams’ experience as you are with the customer experience. In short, happy teams equals happy customers.

* Hire and manage world-class customer success engineers and architects to run 24x7 support operations. Require strong people and project management skills. They need to build relationships, manage performance, and deliver on their commitments.
* Ensure that every customer becomes a reference customer; customers must grow their usage of our open source and commercial software and services substantially over time.
* Relentlessly advocate for the customer - taking the perspective that their success comes first; it isn’t only about whether they know how to run MayaData product A or B correctly, it is about whether they succeed in their use of Kubernetes as a data layer.
* Provide continuous training on OpenEBS and surrounding technologies to the support team to keep them updated with the frequent product releases.
* Be the driver for important customer support calls and make sure that customers get the best experience.
* Continuously improve the customer support process by seeking feedback from customers, field engineers, and developers.
* Drive the development of the content in the MayaData help center through the troubleshooting and solution guides.
* Tune and set up the backend support tools such as ZenDesk and Slack for driving support team productivity.
Point of contact for support escalations.
* Train the support team to be self-sufficient.
* Develop and publish the metrics around customer success to the internal team at regular intervals. Are concerned with many other essential customer service metrics such as first reply time, first contact resolution, handle time, and so on.
* Be part of the bug triage with engineering and product management to help drive the prioritization of customer issues to achieve excellence in customer success.
* CSAT and ESAT surveys are taken to address concerns from both customers and employees.

Key Skills for this role are:

* Communication - You communicate well by building relationships based on trust and respect.
* Direction setting - Building healthy relationships helps you set direction by telling the story of where you’re going and why
* Motivating and recognizing - Building healthy relationships helps you set direction by telling the story of where you’re going and why
* Change management and removing roadblocks - You manage change effectively by using critical thinking to re-design better processes, get buy-in, train people, align everyone’s behavior to those new processes.
* Conflict management, feedback, and development - You handle difficult conflicts on the team by giving tough, fair, but direct feedback.
* Hiring, onboarding, and diversity - Build your team with a lens on diversity and inclusion by hiring great talent and onboarding them well.

### Architect - Customer Success ( aka Field Technologist)

The difference between a Customer Success Engineer and an Architect is experience, subject matter expertise and technical mastery, and their influence in the organization. They’re expected to provide guidance and best practices for providing excelling support for their areas of product expertise. They are trainers and mentors for both customers as well as customer success engineers.

* Customer Success Architects have mastered multiple parts of the product and, operate as liaisons to the Product Management and Development teams, help each of those teams understand where the product can be improved and how
* Customer Success Architects are excellent at communicating complex customer issues to software development teams and can make suggestions for improving the product and influencing the product roadmap.
* Leading developer and user advocacy including coordinating the ever-increasing amount of content being created by the OpenEBS community including MayaData employees and others.
* Personally delivering talks, solution guides, blogs and other forms of communication to help in explaining the benefits and technologies of a container attached storage, OpenEBS, and MayaData software and services.
* Testing scenarios as and Being a first customer shipped for releases of OpenEBS and MayaData software - and demanding a quality-first approach to software that has progressed from the alpha stage into beta and then production quality.
* Delivering ad-hoc projects with partners and MayaData engineers as needed, working with existing solutions and product engineering resources.
* Collaborating with other engineers to develop reference architectures for running a variety of stateful applications in Kubernetes.


Key Skills:

* Must be an experienced software / DevOps engineer who also understands storage and data management and who has experience in explaining technical solutions to a range of personas including storage engineers, open-source developers, SREs, and operations and application architects.
* Experience in assisting enterprises with architecting systems running stateful workloads on or with containers is required.
* A passionate interest in better approaches to improving an enterprise’s capabilities to build and operate stateful workloads is required.
* Experience in storage performance management and in sizing large storage environments for enterprises extremely helpful.
* Design architecture, and development experience in a large software project (internal or open-source) required.

### Senior Architect - Customer Success ( aka Chief Field Technologist)

In addition to the responsibilities defined for Architect - Customer Success, Senior Architects will help with:

* Advocating within the community and within MayaData for the development of capabilities that help users do the jobs they need to do including achieving data agility by running stateful workloads on Kubernetes. Leverage social networks, blog and video platforms, and highly scalable marketing technologies to get the word out.
* Partnering with Sales leadership for “meetings that move the needle” with senior leaders in key accounts
* Positioning and highlighting MayaData and its employees as a technical thought leader, both online and offline

Key Skills:
* Experience leading initiatives in transformation (Cloud migration, Storage migration, DevOps or Agile)
* Aware of industry trends in order to gain a deeper product understanding
* Experience writing books, developing video content, and/or speaking to large audiences is required.

## Hiring Process

All interviews are conducted using Zoom video conferencing software or Google Hangouts or in person. To learn more about someone conducting your interview, find their job title on our team page.

Please keep in mind that you can be declined at any stage of the process. You should consider each of the following bullets as though the words, "If selected" precedes them.
- You will receive a technical questionnaire to complete.
- You will be invited to schedule a 30 minute screening call.
- You will discuss your technical skills for 60 minutes with a member of the Customer Success team.
- You will have 2-3, 45 minute team interviews with at least one Lead Customer Success Engineer.
- You will talk for 60 minutes with a Customer Success hiring manager.

It's possible you may have additional 60 minute interviews with the Directors of Infrastructure Engineering, Engineering, User Adoption, Product Management depending on the Level of the role.

If approved, you will subsequently be made an offer.

Additional details about our process can be found on our [hiring page](https://github.com/mayadata-io/culture/blob/master/process/hiring.md).

We are an equal opportunity employer and value diversity and inclusion at our company. We do not discriminate on the basis of race, religion, color, national origin, gender, sexual orientation, age, marital status, veteran status, or disability status.
