# Frontend Engineer

{{#include intro.md}}

## Responsibilities
- Develop features and improvements to the product in a well-tested and performant way.
- Develop features that meet the internationalization and localization best practices/standards.
- Develop UI that supports white labeling.
- Experienced in instrumenting the product to help with AB testing of new features.
- Participate in the proper [code-reviews](/craft/code-review.md).
- Work with Product Management and other stakeholders (Backend, UX, etc.) to iterate on new features.
- Craft code that meets our internal standards for quality, style, maintainability, and best practices for a high-scale web environment. Maintain and advocate for these standards through code review.
- Confidently ship small features and improvements with minimal guidance and support from other team members. Collaborate and guide your team on larger projects.
- Help improve the overall experience of our product through improving the quality of the Frontend features both in your and other teams.
- Help identify areas of improvements in the code base, both specific to your team and outside your team (eg. component library) and help in contributing back to make it better
- Fix prioritized issues from the issue tracker.
- Advocate for improvements to product quality, security, and performance that have particular impact across your team.
- Solve technical problems of high scope and complexity.
- Exert influence on the overall objectives and long-range goals of your team.
- Experience with performance and optimization problems, particularly at large scale, and a demonstrated ability to both diagnose and prevent these problems.
- Represent MayaData and its values in public forums and conferences around broader initiatives, specific projects, and community contributions.
- Provide mentorship for junior engineers in your team to help them grow in their technical responsibilities.

## Frontend Engineer Levels

### Intern Frontend Engineer
Intern Frontend Engineers, while sharing the same requirements and responsibilities outlined above, typically join with less or alternate experience than typical Frontend Engineers.

### Junior Frontend Engineer
Intermediate Frontend Engineers are expected to meet the requirements and execute the responsibilities with minimal assistance.

### Frontend Engineer
As described above.

### Senior Frontend Engineer
The Senior Frontend Engineer role extends the Frontend Engineer role. Additional responsibilities include:

- Advocate for improvements to product quality, security, and performance that have particular impact across your team.
- Solve technical problems of high scope and complexity.
- Exert influence on the overall objectives and long-range goals of your team. This could be technical and/or product focused.
- Actively participate at product grooming sessions. Help Lead Engineer to drive their area of responsibilities.
- Experience with performance and optimization problems, particularly at large scale, and a demonstrated ability to both diagnose and prevent these problems
- Help to define and improve our internal standards for style, maintainability, and best practices for a high-scale web environment.
- Represent MayaData and its values in public communication around broader initiatives, specific projects, and community contributions.
- Provide mentorship for Junior and Intermediate Engineers in your section to help them grow in their technical responsibilities and remove blockers to their autonomy.
- Confidently ship moderately sized features and improvements with minimal guidance and support from other team members. Collaborate with the team on larger projects.
- Improves the engineering projects at MayaData via maintainer trainee program at own comfortable pace, while striving to become a project maintainer.


## Requirements

- Professional experience with at least one modern JavaScript web MVC framework/library (React, Angular, Ember, VueJS).
- Experience with UI automation test frameworks (eg. Selenium, cypress, Jest).
- Experience using Git in the workplace environment.
- A solid understanding in core web and browser concepts (eg. how HTTP protocol works, what are the verbs, etc.).
- A solid understanding of HTML, CSS, and core JavaScript concepts.
- A solid understanding of REST principles.
- Proficiency in the English language, both written and verbal.
- Demonstrated capacity to clearly and concisely communicate about complex technical, architectural, and/or organizational problems and propose thorough iterative solutions.
- Experience with performance and optimization problems and a demonstrated ability to both diagnose and prevent these problems
- Comfortable working in a highly agile, intensely iterative software development process.
- Demonstrated ability to onboard and integrate with an organization for a long-term.
- Positive and solution-oriented mindset.
- Effective communication skills: Regularly achieve consensus with peers and clear status updates
- Self-motivated and self-managing.
- Demonstrated ability to work closely with other parts of the organization.
- Ability to thrive in a fully remote organization.

**The following are considered a plus**:
- Experience working with a global, remote team or otherwise multicultural team.
- Experience in a high-performance organization, preferably a tech startup.
- Experience contributing to open-source software.
- Experience working as part of cloud-native solutions.
- Domain knowledge of Kubernetes and/or storage.
