# Objectives and Key Results

> “Objectives and key results are the yin and yang of goal setting.” from John Doerr’s Measure What Matters

At MayaData we believe in [PLOW culture](/plow/plow.md) where everyone is committed and accountable to working as a team to deliver company objectives. OKRs provide the best mechanism to gain visibility into everyone’s objectives. OKRs expose redundant efforts and save time and money.

OKRs lay out our plan to execute our strategy and help make sure we achieve them with clearly defined goals throughout the organization.

OKRs help in providing clarity and alignment in terms of what needs to be accomplished by an individual.

OKRs are also a great tool for individuals to stay focused on what they have agreed to accomplish for the company.

OKRs provide both top-down and bottom-up alignment.

OKRs allows managers and individuals to step away from the need for Micromanagement - which is more a sign of mismanagement or an ineffective team composition.

OKRs is a key enabler for our culture that helps each individual to realize their personal dreams and aspirations, while staying committed to helping MayaData customers succeed in their jobs.

## OKRs

[OKRs](https://en.wikipedia.org/wiki/OKR) stand for Objective- Key Results and are our quarterly objectives.

OKRs are of the following format:

```
   OBJECTIVE as a sentence.
   KEY RESULTS:
   * Key result that is measurable
   * Key result that is measurable
   * Key result that is measurable
```

You can use the phrase “I will achieve a certain OBJECTIVE as measured by the following KEY RESULTS…” to know if your OKR makes sense.

OKRs must be defined for each Quarter with a maximum of four objectives. An individual’s OKRs must a mix of:
* 3 Primary role objectives and
* 1 Personal career aspiration objective.

Each objective has between 1 and 4 key results; if you have less, you list less.

The [Startup OKR template](https://medium.com/startup-tools/okrs-5afdc298bc28) provides a good explanation on how to go about writing the OKRs.

> **Objectives:**
>
> The goal of setting> an Objective is to write out what you hope to accomplish such that at a later time you can easily tell if you have reached, or have a clear path to reaching that objective.
>
> Choosing the right objectives is one of the hardest things to do and requires a great deal of thinking and courage to do well.
>
> **Key Results:**
>
> Assuming your Objectives are well thought through, Key Results are the secret sauce to using OKRs. Key Results are numerically-based expressions of success or progress towards an Objective.
>
> The important element here is measuring success. It’s not good enough to make broad statements about improvement (that are subjectively evaluated). We need to know how well you are succeeding. Qualitative goals tend to under-represent our capabilities because the solution tends to be the lowest common denominator.
>
> **Example:**
>
> Consider an objective called `launch new training for the sales team`. This can be accomplished by an individual by putting out a training material out there or by testing the material with a single sales member. However a good key result would be one that can be easily measured and is a stretch - like `train 50 sales team members`. It is possible that the individual can end-up training only 10, but it is better than just publishing or training a single person. The performance of the individual jumped 10-ex with properly articulating the key result.
>
> ```
> OBJECTIVE: launch new training for the sales team
> KEY RESULTS:
> * publish new training material on company portal
> * train 50 sales team members
> ```

OKRs are meant to be ambitious and hard to achieve. Usually, it isn’t expected that anyone hits 100% of an OKR. Expected performance is generally:
* If you hit 70% of the Key Result, it's considered a positive.
* If you hit 110% of the key result, that's a likely sign that the individual and manager who oversaw the OKR didn't manage it well and set the goal too low.
* If you get 50% or less, it's possible that
  * Priorities changed
  * The employee did a poor job working on the objective
  * The Key Result was set poorly (too high).

It takes 2 - 4 quarters to get skilled at setting OKRs; your first few times setting goals you will likely be all over the place in terms of OKR completion at the end of a quarter. That’s normal. As you get better, you should be able to scope out the quarter’s work and performance with more confidence.

## OKR Setting Process

OKR setting is highly collaborative process and takes time and discipline to get it right. OKRs are widely shared and meant to be understood by teams and individuals. Each individual must have their OKRs reviewed by their [Technical Lead](#technical-leads), [People Manager](#people-managers), Peers and/or their [mentor](#mentors).

### OKR cycle

* By the 1st of the quarter, CEO (Company) and Executives (department) OKRs are published. This process typically starts off towards the last month of the previous quarter where CEO and executives meet to plan for the next quarter and align their OKRs.

* By the 15th of the first month in a quarter the OKRs are reviewed and published along with the all-hands. This process involves:
  * Technical or Team Leads publishing their OKRs that are aligned with the CEO/Executive OKRs
  * Individuals share their OKRs in alignment with their Team / Technical Lead OKRs and it is also possible that some of the objectives may be directly aligned towards CEO/Executives. As we taken on cross functional or multiple roles as required by the Startup culture.
  * Individual and Team OKRs are reviewed and updated. The feedback from the Individual OKRs conducted as a team will translate into updating the Team/Technical Lead, Individual or eventually the Executive OKRs.
  * For the personal objectives, the Individual should seek help from People Manager or mentors for review.

* By the 15th of the second month a mid-review score is updated by the individuals

* By the 30th of the third month the final reviews are completed and work on the next Quarters reviews are started.

## Technical Leads

Technical Leads are responsible for a product or a complete feature. Technical Leads have to work with many other individual contributors to accomplish a larger goal.

When the goals set through OKRs are not being accomplished due to any number of reasons including under performing individuals to complex features, the TL can redistribute the tasks to accomplish the goal.

Technical leads are responsible for accomplishing the product/company goal and not responsible for evenly distributing tasks to employees or worrying about the career growth. Individuals have to take ownership for their goals and career growth and seek help from mentors or people managers.

### Types of Meetings with TL
The outcome of each of these meetings is captured in tools or documents that is available for everyone in the company to consume.

* Daily and Weekly Standup
* 1:1 or Team OKR Review Meetings
* 1:1 or Team Knowledge Sharing sessions
* Release Planning
* Design Reviews

## People Managers

People Managers are responsible for helping individuals bring and deliver their best to MayaData. People Manager abide by [PLOW / culture handbook](https://github.com/mayadata-io/culture).

Individuals need to work out with the People managers for their career growth objectives and have them self aligned with the roles and responsibilities outlined in the [culture handbook](https://github.com/mayadata-io/culture).

People Managers are required to update the [PLOW/culture handbook](https://github.com/mayadata-io/culture) when responding to the queries that are common to all the individuals. For instance, [PLOW / culture handbook](https://github.com/mayadata-io/culture) should be referred when answering anything related and not limited to:
* Questions on Leave Management via Tools and Policy
* Event Sponsorships via Developer Advocacy Handbook
* Career Growth via Roles and Responsibilities

People Managers can be reached out to queries or concerns related to Salary and Benefits, which can then be answered via updates to the PLOW policy or through contacting the HR.


### Types of Meetings with People Managers
The outcome of each of these meetings is captured in a document and is confidential between the individual and the people manager. Some outcomes discussed in the meeting that are useful for others in the organization like updating the PLOW can be shared to every-one.
* 1:1 Performance Review Meetings scheduled at least monthly and increasing the frequency depending on the individual’s needs.
* On-demand meetings with Manager or the People Ops contact to discuss about burn-out situations, personal emergencies, vacation planning, PLOW values violation and so forth.

## Mentors

Mentors are experts or have experience in a given area/topic and others in the organization can seek the help from Mentors to learn or gain experience in that area/topic.

Anyone can be mentors. Mentors can be senior or junior in experience than the mentee.

Mentor:mentee sessions are completely optional and if taken, must be taken seriously. The PLOW values of committing and respecting also apply to Mentor:mentee meetings. Schedule and prepare for the meetings with a clear agenda. Once the goals are met, discuss and either reduce the frequency or end the sessions. Make room for other learning experiences.

Mentor discussions should not be confused with better performance reviews or salary discussions, that must be had with [People Managers](#people-managers).

Mentor sessions are inherently meant to be only individual centric, positive and objective to foster learning. Avoid using these sessions to provide negative feedback on others in the organization. You can also seek help or learn on how to handle hard situations or how to better communicate - without turning the sessions into venting channels. Use people ops communication channels to report any violation of [PLOW values](https://github.com/mayadata-io/culture).

Mentors are required to abide by the PLOW values and help improve them.

### Types of Meetings with Mentors
The outcome of each of these meetings is captured in a document that is shared between the mentor and mentee and some information that is useful in a positive way can be shared to every-one.
* 1:1 Mentor-mentee meetings with frequency as decided by the mentor and mentee.

## References

* [Startup OKR Template](https://docs.google.com/document/d/1OHpQOvZz76_10ebJP2AKvvXUF3H9yd6FC89F5jS4mks/edit?pli=1)
* [Excel Template for storing overall objectives and key results]( https://docs.google.com/spreadsheets/d/1kZvIIHO53n4PoiytQBUKcnbCoXx23kcsbcAKO2vUz40/edit#gid=1351340186)
